==> q3-ui-emaileditor-1.39.0.tgz: package/lib/tests/integration/emaileditor.test.js <==
"use strict";

require("../helpers/polyfillRange");

var _react = _interopRequireDefault(require("react"));

var utils = _interopRequireWildcard(require("q3-ui-test-utils/lib/enzymeUtils"));

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _lab = require("@material-ui/lab");

var _ = _interopRequireDefault(require("../.."));

var _EmailEditorErrorGraphic = _interopRequireDefault(require("../../components/EmailEditorErrorGraphic"));

var _fixtures = _interopRequireDefault(require("../fixtures"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.unmock('axios');
jest.unmock('notistack');
describe('EmailEditor', () => {
  it('should fetch', async () => {
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 5000
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    expect(el.find(_CircularProgress.default).exists()).toBeTruthy();
  });
  it('should error', async () => {
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 0,
      causeError: true
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    expect(el.find(_EmailEditorErrorGraphic.default).exists()).toBeTruthy();
  });
  it('should generate previews for full templates', async () => {
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 0
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    await utils.asyncAct(async () => {
      // debounced preview call
      await utils.wait(2000);
      return el;
    });
    const iframe = el.find('iframe');
    expect(iframe.exists()).toBeTruthy();
    expect(iframe.prop('data-test')).toMatch('Preview');
    await utils.asyncAct(() => {
      // simulating TreeItem click doesn't work
      el.find(_lab.TreeView).prop('onNodeSelect')(null, 't1');
      return el;
    });
    expect(el.find('iframe').exists()).toBeFalsy();
  });
  it('should save MJML changes', async () => {
    const newValue = '<mjml><mj-body><mj-text>Changed.</mj-text></mj-body></mjml>';
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 0
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    await utils.asyncAct(() => {
      el.find('textarea').prop('data-test').setValue(newValue);
      return el;
    });
    await utils.asyncAct(async () => {
      // debounced save call
      await el.find('#save-email-template').first().simulate('click');
      return el;
    });
    await utils.asyncAct(async () => {
      // debounced save call
      await utils.wait(500);
      return el;
    });
    expect(el.find('textarea').prop('data-value')).toMatch(newValue);
  });
});

==> q3-ui-emaileditor-3.16.4.tgz: package/lib/tests/integration/emaileditor.test.js <==
"use strict";

require("../helpers/polyfillRange");

var _react = _interopRequireDefault(require("react"));

var utils = _interopRequireWildcard(require("q3-ui-test-utils/lib/enzymeUtils"));

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _lab = require("@material-ui/lab");

var _ = _interopRequireDefault(require("../.."));

var _EmailEditorErrorGraphic = _interopRequireDefault(require("../../components/EmailEditorErrorGraphic"));

var _fixtures = _interopRequireDefault(require("../fixtures"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.unmock('axios');
jest.unmock('notistack');
describe('EmailEditor', () => {
  it('should fetch', async () => {
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 5000
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    expect(el.find(_CircularProgress.default).exists()).toBeTruthy();
  });
  it('should error', async () => {
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 0,
      causeError: true
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    expect(el.find(_EmailEditorErrorGraphic.default).exists()).toBeTruthy();
  });
  it('should generate previews for full templates', async () => {
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 0
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    await utils.asyncAct(async () => {
      // debounced preview call
      await utils.wait(2000);
      return el;
    });
    const iframe = el.find('iframe');
    expect(iframe.exists()).toBeTruthy();
    expect(iframe.prop('data-test')).toMatch('Preview');
    await utils.asyncAct(() => {
      // simulating TreeItem click doesn't work
      el.find(_lab.TreeView).prop('onNodeSelect')(null, 't1');
      return el;
    });
    expect(el.find('iframe').exists()).toBeFalsy();
  });
  it('should save MJML changes', async () => {
    const newValue = '<mjml><mj-body><mj-text>Changed.</mj-text></mj-body></mjml>';
    const el = await utils.asyncMount( /*#__PURE__*/_react.default.createElement(_fixtures.default, {
      delay: 0
    }, /*#__PURE__*/_react.default.createElement(_.default, null)));
    await utils.asyncAct(() => {
      el.find('textarea').prop('data-test').setValue(newValue);
      return el;
    });
    await utils.asyncAct(async () => {
      // debounced save call
      await el.find('#save-email-template').first().simulate('click');
      return el;
    });
    await utils.asyncAct(async () => {
      // debounced save call
      await utils.wait(500);
      return el;
    });
    expect(el.find('textarea').prop('data-value')).toMatch(newValue);
  });
});
